@@ -7,13 +7,13 @@ const wabt = require("wabt");
 
 const {
   getFixtures,
-  compareWithExpected
+  compareWithExpected,
 } = require("@webassemblyjs/helper-test-framework");
 
 function errorsToString(arr) {
   return arr
-    .map(x => x.trim())
-    .filter(s => s.length > 0)
+    .map((x) => x.trim())
+    .filter((s) => s.length > 0)
     .join("\n");
 }
 
@@ -21,7 +21,7 @@ describe("validation", () => {
   const testSuites = getFixtures(__dirname, "fixtures", "**/module.wast");
 
   describe("wast", () => {
-    const pre = f => {
+    const pre = (f) => {
       const errors = validations.getValidationErrors(parse(f));
 
       return errorsToString(errors);
