@@ -2,7 +2,7 @@
 
 const {
   getFixtures,
-  compareWithExpected
+  compareWithExpected,
 } = require("@webassemblyjs/helper-test-framework");
 const { parse } = require("@webassemblyjs/wast-parser");
 
@@ -11,7 +11,7 @@ const { print } = require("../lib/index");
 describe("printer", () => {
   describe("wast", () => {
     const testSuites = getFixtures(__dirname, "fixtures", "**/actual.wast");
-    const pre = f => print(parse(f));
+    const pre = (f) => print(parse(f));
 
     compareWithExpected(testSuites, pre, "expected.wast");
   });
