@@ -5,6 +5,6 @@ const type = "label";
 export function createValue(value: string): StackLocal {
   return {
     type,
-    value
+    value,
   };
 }
