@@ -9,17 +9,17 @@ const { i32 } = require("../../../../lib/interpreter/runtime/values/i32");
 const { i64 } = require("../../../../lib/interpreter/runtime/values/i64");
 const {
   f32,
-  f32nan
+  f32nan,
 } = require("../../../../lib/interpreter/runtime/values/f32");
 const { f64 } = require("../../../../lib/interpreter/runtime/values/f64");
 const {
-  castIntoStackLocalOfType
+  castIntoStackLocalOfType,
 } = require("../../../../lib/interpreter/runtime/castIntoStackLocalOfType");
 const {
-  executeStackFrame
+  executeStackFrame,
 } = require("../../../../lib/interpreter/kernel/exec");
 const {
-  createStackFrame
+  createStackFrame,
 } = require("../../../../lib/interpreter/kernel/stackframe");
 const { compileASTNodes } = require("@webassemblyjs/helper-test-framework");
 
@@ -47,71 +47,86 @@ describe("kernel exec - numeric instructions", () => {
     {
       name: "i32.add",
 
-      args: [{ value: 1, type: "i32" }, { value: 1, type: "i32" }],
+      args: [
+        { value: 1, type: "i32" },
+        { value: 1, type: "i32" },
+      ],
 
       code: [
         t.instruction("get_local", [t.numberLiteralFromRaw(0)]),
         t.instruction("get_local", [t.numberLiteralFromRaw(1)]),
-        t.objectInstruction("add", "i32")
+        t.objectInstruction("add", "i32"),
       ],
 
-      resEqual: new i32(2)
+      resEqual: new i32(2),
     },
 
     {
       name: "i32.sub",
 
-      args: [{ value: 1, type: "i32" }, { value: 1, type: "i32" }],
+      args: [
+        { value: 1, type: "i32" },
+        { value: 1, type: "i32" },
+      ],
 
       code: [
         t.instruction("get_local", [t.numberLiteralFromRaw(0)]),
         t.instruction("get_local", [t.numberLiteralFromRaw(1)]),
-        t.objectInstruction("sub", "i32")
+        t.objectInstruction("sub", "i32"),
       ],
 
-      resEqual: new i32(0)
+      resEqual: new i32(0),
     },
 
     {
       name: "i32.mul",
 
-      args: [{ value: 2, type: "i32" }, { value: 1, type: "i32" }],
+      args: [
+        { value: 2, type: "i32" },
+        { value: 1, type: "i32" },
+      ],
 
       code: [
         t.instruction("get_local", [t.numberLiteralFromRaw(0)]),
         t.instruction("get_local", [t.numberLiteralFromRaw(1)]),
-        t.objectInstruction("mul", "i32")
+        t.objectInstruction("mul", "i32"),
       ],
 
-      resEqual: new i32(2)
+      resEqual: new i32(2),
     },
 
     {
       name: "i32.div_s",
 
-      args: [{ value: 10, type: "i32" }, { value: 2, type: "i32" }],
+      args: [
+        { value: 10, type: "i32" },
+        { value: 2, type: "i32" },
+      ],
 
       code: [
         t.instruction("get_local", [t.numberLiteralFromRaw(0)]),
         t.instruction("get_local", [t.numberLiteralFromRaw(1)]),
-        t.objectInstruction("div_s", "i32")
+        t.objectInstruction("div_s", "i32"),
       ],
 
-      resEqual: new i32(5)
+      resEqual: new i32(5),
     },
 
     {
       name: "i32.div_u",
 
-      args: [{ value: 10, type: "i32" }, { value: 2, type: "i32" }],
+      args: [
+        { value: 10, type: "i32" },
+        { value: 2, type: "i32" },
+      ],
 
       code: [
         t.instruction("get_local", [t.numberLiteralFromRaw(0)]),
         t.instruction("get_local", [t.numberLiteralFromRaw(1)]),
-        t.objectInstruction("div_u", "i32")
+        t.objectInstruction("div_u", "i32"),
       ],
 
-      resEqual: new i32(5)
+      resEqual: new i32(5),
     },
 
     /**
@@ -123,16 +138,16 @@ describe("kernel exec - numeric instructions", () => {
 
       args: [
         { value: Long.fromString("10001001110010", false, 2), type: "i64" },
-        { value: Long.fromString("10001001010010", false, 2), type: "i64" }
+        { value: Long.fromString("10001001010010", false, 2), type: "i64" },
       ],
 
       code: [
         t.instruction("get_local", [t.numberLiteralFromRaw(0)]),
         t.instruction("get_local", [t.numberLiteralFromRaw(1)]),
-        t.objectInstruction("and", "i64")
+        t.objectInstruction("and", "i64"),
       ],
 
-      resEqual: new i64(Long.fromString("10001001010010", false, 2))
+      resEqual: new i64(Long.fromString("10001001010010", false, 2)),
     },
 
     {
@@ -140,16 +155,16 @@ describe("kernel exec - numeric instructions", () => {
 
       args: [
         { value: Long.fromString("10001001110010", false, 2), type: "i64" },
-        { value: Long.fromString("10001011010010", false, 2), type: "i64" }
+        { value: Long.fromString("10001011010010", false, 2), type: "i64" },
       ],
 
       code: [
         t.instruction("get_local", [t.numberLiteralFromRaw(0)]),
         t.instruction("get_local", [t.numberLiteralFromRaw(1)]),
-        t.objectInstruction("or", "i64")
+        t.objectInstruction("or", "i64"),
       ],
 
-      resEqual: new i64(Long.fromString("10001011110010", false, 2))
+      resEqual: new i64(Long.fromString("10001011110010", false, 2)),
     },
 
     {
@@ -157,16 +172,16 @@ describe("kernel exec - numeric instructions", () => {
 
       args: [
         { value: Long.fromString("10001001110010", false, 2), type: "i64" },
-        { value: Long.fromString("10001011010010", false, 2), type: "i64" }
+        { value: Long.fromString("10001011010010", false, 2), type: "i64" },
       ],
 
       code: [
         t.instruction("get_local", [t.numberLiteralFromRaw(0)]),
         t.instruction("get_local", [t.numberLiteralFromRaw(1)]),
-        t.objectInstruction("xor", "i64")
+        t.objectInstruction("xor", "i64"),
       ],
 
-      resEqual: new i64(Long.fromString("00000010100000", false, 2))
+      resEqual: new i64(Long.fromString("00000010100000", false, 2)),
     },
 
     {
@@ -174,16 +189,16 @@ describe("kernel exec - numeric instructions", () => {
 
       args: [
         { value: Long.fromString("1844674407370955161"), type: "i64" },
-        { value: Long.fromString("1"), type: "i64" }
+        { value: Long.fromString("1"), type: "i64" },
       ],
 
       code: [
         t.instruction("get_local", [t.numberLiteralFromRaw(0)]),
         t.instruction("get_local", [t.numberLiteralFromRaw(1)]),
-        t.objectInstruction("add", "i64")
+        t.objectInstruction("add", "i64"),
       ],
 
-      resEqual: new i64(Long.fromString("1844674407370955162"))
+      resEqual: new i64(Long.fromString("1844674407370955162")),
     },
 
     {
@@ -191,16 +206,16 @@ describe("kernel exec - numeric instructions", () => {
 
       args: [
         { value: Long.fromString("1844674407370955161"), type: "i64" },
-        { value: Long.fromString("1"), type: "i64" }
+        { value: Long.fromString("1"), type: "i64" },
       ],
 
       code: [
         t.instruction("get_local", [t.numberLiteralFromRaw(0)]),
         t.instruction("get_local", [t.numberLiteralFromRaw(1)]),
-        t.objectInstruction("sub", "i64")
+        t.objectInstruction("sub", "i64"),
       ],
 
-      resEqual: new i64(Long.fromString("1844674407370955160"))
+      resEqual: new i64(Long.fromString("1844674407370955160")),
     },
 
     {
@@ -208,16 +223,16 @@ describe("kernel exec - numeric instructions", () => {
 
       args: [
         { value: Long.fromString("2"), type: "i64" },
-        { value: Long.fromString("1844674407370955161"), type: "i64" }
+        { value: Long.fromString("1844674407370955161"), type: "i64" },
       ],
 
       code: [
         t.instruction("get_local", [t.numberLiteralFromRaw(0)]),
         t.instruction("get_local", [t.numberLiteralFromRaw(1)]),
-        t.objectInstruction("mul", "i64")
+        t.objectInstruction("mul", "i64"),
       ],
 
-      resEqual: new i64(Long.fromString("3689348814741910322"))
+      resEqual: new i64(Long.fromString("3689348814741910322")),
     },
 
     {
@@ -225,16 +240,16 @@ describe("kernel exec - numeric instructions", () => {
 
       args: [
         { value: Long.fromString("1844674407370955160"), type: "i64" },
-        { value: Long.fromString("2"), type: "i64" }
+        { value: Long.fromString("2"), type: "i64" },
       ],
 
       code: [
         t.instruction("get_local", [t.numberLiteralFromRaw(0)]),
         t.instruction("get_local", [t.numberLiteralFromRaw(1)]),
-        t.objectInstruction("div_s", "i64")
+        t.objectInstruction("div_s", "i64"),
       ],
 
-      resEqual: new i64(Long.fromString("922337203685477580"))
+      resEqual: new i64(Long.fromString("922337203685477580")),
     },
 
     {
@@ -242,16 +257,16 @@ describe("kernel exec - numeric instructions", () => {
 
       args: [
         { value: Long.fromString("1844674407370955160"), type: "i64" },
-        { value: Long.fromString("2"), type: "i64" }
+        { value: Long.fromString("2"), type: "i64" },
       ],
 
       code: [
         t.instruction("get_local", [t.numberLiteralFromRaw(0)]),
         t.instruction("get_local", [t.numberLiteralFromRaw(1)]),
-        t.objectInstruction("div_u", "i64")
+        t.objectInstruction("div_u", "i64"),
       ],
 
-      resEqual: new i64(Long.fromString("922337203685477580"))
+      resEqual: new i64(Long.fromString("922337203685477580")),
     },
 
     /**
@@ -261,29 +276,35 @@ describe("kernel exec - numeric instructions", () => {
     {
       name: "f32.add",
 
-      args: [{ value: 1.0, type: "f32" }, { value: 1.0, type: "f32" }],
+      args: [
+        { value: 1.0, type: "f32" },
+        { value: 1.0, type: "f32" },
+      ],
 
       code: [
         t.instruction("get_local", [t.numberLiteralFromRaw(0)]),
         t.instruction("get_local", [t.numberLiteralFromRaw(1)]),
-        t.objectInstruction("add", "f32")
+        t.objectInstruction("add", "f32"),
       ],
 
-      resEqual: new f32(2)
+      resEqual: new f32(2),
     },
 
     {
       name: "f32.add",
 
-      args: [{ value: 1, type: "f32", nan: true }, { value: 1.0, type: "f32" }],
+      args: [
+        { value: 1, type: "f32", nan: true },
+        { value: 1.0, type: "f32" },
+      ],
 
       code: [
         t.instruction("get_local", [t.numberLiteralFromRaw(0)]),
         t.instruction("get_local", [t.numberLiteralFromRaw(1)]),
-        t.objectInstruction("add", "f32")
+        t.objectInstruction("add", "f32"),
       ],
 
-      resEqual: new f32nan(1)
+      resEqual: new f32nan(1),
     },
 
     {
@@ -291,16 +312,16 @@ describe("kernel exec - numeric instructions", () => {
 
       args: [
         { value: -31.4, type: "f32" },
-        { value: 4747, type: "f32", nan: true }
+        { value: 4747, type: "f32", nan: true },
       ],
 
       code: [
         t.instruction("get_local", [t.numberLiteralFromRaw(0)]),
         t.instruction("get_local", [t.numberLiteralFromRaw(1)]),
-        t.objectInstruction("add", "f32")
+        t.objectInstruction("add", "f32"),
       ],
 
-      resEqual: new f32nan(4747)
+      resEqual: new f32nan(4747),
     },
 
     {
@@ -308,32 +329,35 @@ describe("kernel exec - numeric instructions", () => {
 
       args: [
         { value: 777, type: "f32", nan: true },
-        { value: 4747, type: "f32", nan: true }
+        { value: 4747, type: "f32", nan: true },
       ],
 
       code: [
         t.instruction("get_local", [t.numberLiteralFromRaw(0)]),
         t.instruction("get_local", [t.numberLiteralFromRaw(1)]),
-        t.objectInstruction("add", "f32")
+        t.objectInstruction("add", "f32"),
       ],
 
       // The payload is not required to be the second operands one,
       // but for consistency we can always do so
-      resEqual: new f32nan(777)
+      resEqual: new f32nan(777),
     },
 
     {
       name: "f32.sub",
 
-      args: [{ value: 1.0, type: "f32" }, { value: 1.0, type: "f32" }],
+      args: [
+        { value: 1.0, type: "f32" },
+        { value: 1.0, type: "f32" },
+      ],
 
       code: [
         t.instruction("get_local", [t.numberLiteralFromRaw(0)]),
         t.instruction("get_local", [t.numberLiteralFromRaw(1)]),
-        t.objectInstruction("sub", "f32")
+        t.objectInstruction("sub", "f32"),
       ],
 
-      resEqual: new f32(0)
+      resEqual: new f32(0),
     },
 
     {
@@ -341,16 +365,16 @@ describe("kernel exec - numeric instructions", () => {
 
       args: [
         { value: 232111, type: "f32", nan: true },
-        { value: 1.0, type: "f32" }
+        { value: 1.0, type: "f32" },
       ],
 
       code: [
         t.instruction("get_local", [t.numberLiteralFromRaw(0)]),
         t.instruction("get_local", [t.numberLiteralFromRaw(1)]),
-        t.objectInstruction("sub", "f32")
+        t.objectInstruction("sub", "f32"),
       ],
 
-      resEqual: new f32nan(232111)
+      resEqual: new f32nan(232111),
     },
 
     {
@@ -358,16 +382,16 @@ describe("kernel exec - numeric instructions", () => {
 
       args: [
         { value: 232111, type: "f32", nan: true },
-        { value: 1, type: "f32", nan: true }
+        { value: 1, type: "f32", nan: true },
       ],
 
       code: [
         t.instruction("get_local", [t.numberLiteralFromRaw(0)]),
         t.instruction("get_local", [t.numberLiteralFromRaw(1)]),
-        t.objectInstruction("sub", "f32")
+        t.objectInstruction("sub", "f32"),
       ],
 
-      resEqual: new f32nan(232111)
+      resEqual: new f32nan(232111),
     },
 
     {
@@ -375,44 +399,50 @@ describe("kernel exec - numeric instructions", () => {
 
       args: [
         { value: 232111, type: "f32" },
-        { value: 1, type: "f32", nan: true }
+        { value: 1, type: "f32", nan: true },
       ],
 
       code: [
         t.instruction("get_local", [t.numberLiteralFromRaw(0)]),
         t.instruction("get_local", [t.numberLiteralFromRaw(1)]),
-        t.objectInstruction("sub", "f32")
+        t.objectInstruction("sub", "f32"),
       ],
 
-      resEqual: new f32nan(1)
+      resEqual: new f32nan(1),
     },
 
     {
       name: "f32.mul",
 
-      args: [{ value: 2.0, type: "f32" }, { value: 1.0, type: "f32" }],
+      args: [
+        { value: 2.0, type: "f32" },
+        { value: 1.0, type: "f32" },
+      ],
 
       code: [
         t.instruction("get_local", [t.numberLiteralFromRaw(0)]),
         t.instruction("get_local", [t.numberLiteralFromRaw(1)]),
-        t.objectInstruction("mul", "f32")
+        t.objectInstruction("mul", "f32"),
       ],
 
-      resEqual: new f32(2)
+      resEqual: new f32(2),
     },
 
     {
       name: "f32.mul",
 
-      args: [{ value: 2, type: "f32", nan: true }, { value: 1.0, type: "f32" }],
+      args: [
+        { value: 2, type: "f32", nan: true },
+        { value: 1.0, type: "f32" },
+      ],
 
       code: [
         t.instruction("get_local", [t.numberLiteralFromRaw(0)]),
         t.instruction("get_local", [t.numberLiteralFromRaw(1)]),
-        t.objectInstruction("mul", "f32")
+        t.objectInstruction("mul", "f32"),
       ],
 
-      resEqual: new f32nan(2)
+      resEqual: new f32nan(2),
     },
 
     {
@@ -420,72 +450,84 @@ describe("kernel exec - numeric instructions", () => {
 
       args: [
         { value: 0, type: "f32", nan: true },
-        { value: 1, type: "f32", nan: true }
+        { value: 1, type: "f32", nan: true },
       ],
 
       code: [
         t.instruction("get_local", [t.numberLiteralFromRaw(0)]),
         t.instruction("get_local", [t.numberLiteralFromRaw(1)]),
-        t.objectInstruction("mul", "f32")
+        t.objectInstruction("mul", "f32"),
       ],
 
-      resEqual: new f32nan(0)
+      resEqual: new f32nan(0),
     },
 
     {
       name: "f32.mul",
 
-      args: [{ value: 0, type: "f32" }, { value: 177, type: "f32", nan: true }],
+      args: [
+        { value: 0, type: "f32" },
+        { value: 177, type: "f32", nan: true },
+      ],
 
       code: [
         t.instruction("get_local", [t.numberLiteralFromRaw(0)]),
         t.instruction("get_local", [t.numberLiteralFromRaw(1)]),
-        t.objectInstruction("mul", "f32")
+        t.objectInstruction("mul", "f32"),
       ],
 
-      resEqual: new f32nan(177)
+      resEqual: new f32nan(177),
     },
 
     {
       name: "f32.div",
 
-      args: [{ value: 10.0, type: "f32" }, { value: 2.0, type: "f32" }],
+      args: [
+        { value: 10.0, type: "f32" },
+        { value: 2.0, type: "f32" },
+      ],
 
       code: [
         t.instruction("get_local", [t.numberLiteralFromRaw(0)]),
         t.instruction("get_local", [t.numberLiteralFromRaw(1)]),
-        t.objectInstruction("div", "f32")
+        t.objectInstruction("div", "f32"),
       ],
 
-      resEqual: new f32(5.0)
+      resEqual: new f32(5.0),
     },
 
     {
       name: "f32.min",
 
-      args: [{ value: 5.0, type: "f32" }, { value: 1000.7, type: "f32" }],
+      args: [
+        { value: 5.0, type: "f32" },
+        { value: 1000.7, type: "f32" },
+      ],
 
       code: [
         t.instruction("get_local", [t.numberLiteralFromRaw(0)]),
         t.instruction("get_local", [t.numberLiteralFromRaw(1)]),
-        t.objectInstruction("min", "f32")
+        t.objectInstruction("min", "f32"),
       ],
 
-      resEqual: new f32(5.0)
+      resEqual: new f32(5.0),
     },
 
     {
       name: "f32.min",
 
-      args: [{ value: +0, type: "f32" }, { value: -0, type: "f32" }],
+      args: [
+        { value: +0, type: "f32" },
+        { value: -0, type: "f32" },
+      ],
 
       code: [
         t.instruction("get_local", [t.numberLiteralFromRaw(0)]),
         t.instruction("get_local", [t.numberLiteralFromRaw(1)]),
-        t.objectInstruction("min", "f32")
+        t.objectInstruction("min", "f32"),
       ],
 
-      resEqual: new f32(-0)
+      resEqual: new f32(-0),
     },
 
     {
@@ -493,44 +535,50 @@ describe("kernel exec - numeric instructions", () => {
 
       args: [
         { value: Infinity, type: "f32" },
-        { value: -Infinity, type: "f32" }
+        { value: -Infinity, type: "f32" },
       ],
 
       code: [
         t.instruction("get_local", [t.numberLiteralFromRaw(0)]),
         t.instruction("get_local", [t.numberLiteralFromRaw(1)]),
-        t.objectInstruction("min", "f32")
+        t.objectInstruction("min", "f32"),
       ],
 
-      resEqual: new f32(-Infinity)
+      resEqual: new f32(-Infinity),
     },
 
     {
       name: "f32.min",
 
-      args: [{ value: Infinity, type: "f32" }, { value: 1234, type: "f32" }],
+      args: [
+        { value: Infinity, type: "f32" },
+        { value: 1234, type: "f32" },
+      ],
 
       code: [
         t.instruction("get_local", [t.numberLiteralFromRaw(0)]),
         t.instruction("get_local", [t.numberLiteralFromRaw(1)]),
-        t.objectInstruction("min", "f32")
+        t.objectInstruction("min", "f32"),
       ],
 
-      resEqual: new f32(1234)
+      resEqual: new f32(1234),
     },
 
     {
       name: "f32.min",
 
-      args: [{ value: NaN, type: "f32" }, { value: 1234, type: "f32" }],
+      args: [
+        { value: NaN, type: "f32" },
+        { value: 1234, type: "f32" },
+      ],
 
       code: [
         t.instruction("get_local", [t.numberLiteralFromRaw(0)]),
         t.instruction("get_local", [t.numberLiteralFromRaw(1)]),
-        t.objectInstruction("min", "f32")
+        t.objectInstruction("min", "f32"),
       ],
 
-      resEqual: new f32(NaN)
+      resEqual: new f32(NaN),
     },
 
     {
@@ -538,44 +586,50 @@ describe("kernel exec - numeric instructions", () => {
 
       args: [
         { value: 0.0000000000000000000000001, type: "f32" },
-        { value: 0.00000000000000000000000001, type: "f32" }
+        { value: 0.00000000000000000000000001, type: "f32" },
       ],
 
       code: [
         t.instruction("get_local", [t.numberLiteralFromRaw(0)]),
         t.instruction("get_local", [t.numberLiteralFromRaw(1)]),
-        t.objectInstruction("min", "f32")
+        t.objectInstruction("min", "f32"),
       ],
 
-      resEqual: new f32(0.00000000000000000000000001)
+      resEqual: new f32(0.00000000000000000000000001),
     },
 
     {
       name: "f32.max",
 
-      args: [{ value: 5.0, type: "f32" }, { value: 1000.7, type: "f32" }],
+      args: [
+        { value: 5.0, type: "f32" },
+        { value: 1000.7, type: "f32" },
+      ],
 
       code: [
         t.instruction("get_local", [t.numberLiteralFromRaw(0)]),
         t.instruction("get_local", [t.numberLiteralFromRaw(1)]),
-        t.objectInstruction("max", "f32")
+        t.objectInstruction("max", "f32"),
       ],
 
-      resEqual: new f32(1000.7)
+      resEqual: new f32(1000.7),
     },
 
     {
       name: "f32.max",
 
-      args: [{ value: +0, type: "f32" }, { value: -0, type: "f32" }],
+      args: [
+        { value: +0, type: "f32" },
+        { value: -0, type: "f32" },
+      ],
 
       code: [
         t.instruction("get_local", [t.numberLiteralFromRaw(0)]),
         t.instruction("get_local", [t.numberLiteralFromRaw(1)]),
-        t.objectInstruction("max", "f32")
+        t.objectInstruction("max", "f32"),
       ],
 
-      resEqual: new f32(+0)
+      resEqual: new f32(+0),
     },
 
     {
@@ -583,44 +637,50 @@ describe("kernel exec - numeric instructions", () => {
 
       args: [
         { value: Infinity, type: "f32" },
-        { value: -Infinity, type: "f32" }
+        { value: -Infinity, type: "f32" },
       ],
 
       code: [
         t.instruction("get_local", [t.numberLiteralFromRaw(0)]),
         t.instruction("get_local", [t.numberLiteralFromRaw(1)]),
-        t.objectInstruction("max", "f32")
+        t.objectInstruction("max", "f32"),
       ],
 
-      resEqual: new f32(Infinity)
+      resEqual: new f32(Infinity),
     },
 
     {
       name: "f32.max",
 
-      args: [{ value: Infinity, type: "f32" }, { value: 1234, type: "f32" }],
+      args: [
+        { value: Infinity, type: "f32" },
+        { value: 1234, type: "f32" },
+      ],
 
       code: [
         t.instruction("get_local", [t.numberLiteralFromRaw(0)]),
         t.instruction("get_local", [t.numberLiteralFromRaw(1)]),
-        t.objectInstruction("max", "f32")
+        t.objectInstruction("max", "f32"),
       ],
 
-      resEqual: new f32(Infinity)
+      resEqual: new f32(Infinity),
     },
 
     {
       name: "f32.max",
 
-      args: [{ value: NaN, type: "f32" }, { value: 1234, type: "f32" }],
+      args: [
+        { value: NaN, type: "f32" },
+        { value: 1234, type: "f32" },
+      ],
 
       code: [
         t.instruction("get_local", [t.numberLiteralFromRaw(0)]),
         t.instruction("get_local", [t.numberLiteralFromRaw(1)]),
-        t.objectInstruction("max", "f32")
+        t.objectInstruction("max", "f32"),
       ],
 
-      resEqual: new f32(NaN)
+      resEqual: new f32(NaN),
     },
 
     {
@@ -628,16 +688,16 @@ describe("kernel exec - numeric instructions", () => {
 
       args: [
         { value: 0.0000000000000000000000001, type: "f32" },
-        { value: 0.00000000000000000000000001, type: "f32" }
+        { value: 0.00000000000000000000000001, type: "f32" },
       ],
 
       code: [
         t.instruction("get_local", [t.numberLiteralFromRaw(0)]),
         t.instruction("get_local", [t.numberLiteralFromRaw(1)]),
-        t.objectInstruction("max", "f32")
+        t.objectInstruction("max", "f32"),
       ],
 
-      resEqual: new f32(0.0000000000000000000000001)
+      resEqual: new f32(0.0000000000000000000000001),
     },
 
     /**
@@ -647,85 +707,103 @@ describe("kernel exec - numeric instructions", () => {
     {
       name: "f64.add",
 
-      args: [{ value: 1.0, type: "f64" }, { value: 1.0, type: "f64" }],
+      args: [
+        { value: 1.0, type: "f64" },
+        { value: 1.0, type: "f64" },
+      ],
 
       code: [
         t.instruction("get_local", [t.numberLiteralFromRaw(0)]),
         t.instruction("get_local", [t.numberLiteralFromRaw(1)]),
-        t.objectInstruction("add", "f64")
+        t.objectInstruction("add", "f64"),
       ],
 
-      resEqual: new f64(2.0)
+      resEqual: new f64(2.0),
     },
 
     {
       name: "f64.sub",
 
-      args: [{ value: 1.0, type: "f64" }, { value: 1.0, type: "f64" }],
+      args: [
+        { value: 1.0, type: "f64" },
+        { value: 1.0, type: "f64" },
+      ],
 
       code: [
         t.instruction("get_local", [t.numberLiteralFromRaw(0)]),
         t.instruction("get_local", [t.numberLiteralFromRaw(1)]),
-        t.objectInstruction("sub", "f64")
+        t.objectInstruction("sub", "f64"),
       ],
 
-      resEqual: new f64(0)
+      resEqual: new f64(0),
     },
 
     {
       name: "f64.mul",
 
-      args: [{ value: 2.0, type: "f64" }, { value: 1.0, type: "f64" }],
+      args: [
+        { value: 2.0, type: "f64" },
+        { value: 1.0, type: "f64" },
+      ],
 
       code: [
         t.instruction("get_local", [t.numberLiteralFromRaw(0)]),
         t.instruction("get_local", [t.numberLiteralFromRaw(1)]),
-        t.objectInstruction("mul", "f64")
+        t.objectInstruction("mul", "f64"),
       ],
 
-      resEqual: new f64(2.0)
+      resEqual: new f64(2.0),
     },
 
     {
       name: "f64.div",
 
-      args: [{ value: 10.0, type: "f64" }, { value: 2.0, type: "f64" }],
+      args: [
+        { value: 10.0, type: "f64" },
+        { value: 2.0, type: "f64" },
+      ],
 
       code: [
         t.instruction("get_local", [t.numberLiteralFromRaw(0)]),
         t.instruction("get_local", [t.numberLiteralFromRaw(1)]),
-        t.objectInstruction("div", "f64")
+        t.objectInstruction("div", "f64"),
       ],
 
-      resEqual: new f64(5.0)
+      resEqual: new f64(5.0),
     },
 
     {
       name: "f64.min",
 
-      args: [{ value: 5.0, type: "f64" }, { value: 1000.7, type: "f64" }],
+      args: [
+        { value: 5.0, type: "f64" },
+        { value: 1000.7, type: "f64" },
+      ],
 
       code: [
         t.instruction("get_local", [t.numberLiteralFromRaw(0)]),
         t.instruction("get_local", [t.numberLiteralFromRaw(1)]),
-        t.objectInstruction("min", "f64")
+        t.objectInstruction("min", "f64"),
       ],
 
-      resEqual: new f64(5.0)
+      resEqual: new f64(5.0),
     },
 
     {
       name: "f64.min",
 
-      args: [{ value: +0, type: "f64" }, { value: -0, type: "f64" }],
+      args: [
+        { value: +0, type: "f64" },
+        { value: -0, type: "f64" },
+      ],
 
       code: [
         t.instruction("get_local", [t.numberLiteralFromRaw(0)]),
         t.instruction("get_local", [t.numberLiteralFromRaw(1)]),
-        t.objectInstruction("min", "f64")
+        t.objectInstruction("min", "f64"),
       ],
 
-      resEqual: new f64(-0)
+      resEqual: new f64(-0),
     },
 
     {
@@ -733,44 +811,50 @@ describe("kernel exec - numeric instructions", () => {
 
       args: [
         { value: Infinity, type: "f64" },
-        { value: -Infinity, type: "f64" }
+        { value: -Infinity, type: "f64" },
       ],
 
       code: [
         t.instruction("get_local", [t.numberLiteralFromRaw(0)]),
         t.instruction("get_local", [t.numberLiteralFromRaw(1)]),
-        t.objectInstruction("min", "f64")
+        t.objectInstruction("min", "f64"),
       ],
 
-      resEqual: new f64(-Infinity)
+      resEqual: new f64(-Infinity),
     },
 
     {
       name: "f64.min",
 
-      args: [{ value: Infinity, type: "f64" }, { value: 1234, type: "f64" }],
+      args: [
+        { value: Infinity, type: "f64" },
+        { value: 1234, type: "f64" },
+      ],
 
       code: [
         t.instruction("get_local", [t.numberLiteralFromRaw(0)]),
         t.instruction("get_local", [t.numberLiteralFromRaw(1)]),
-        t.objectInstruction("min", "f64")
+        t.objectInstruction("min", "f64"),
       ],
 
-      resEqual: new f64(1234)
+      resEqual: new f64(1234),
     },
 
     {
       name: "f64.min",
 
-      args: [{ value: NaN, type: "f64" }, { value: 1234, type: "f64" }],
+      args: [
+        { value: NaN, type: "f64" },
+        { value: 1234, type: "f64" },
+      ],
 
       code: [
         t.instruction("get_local", [t.numberLiteralFromRaw(0)]),
         t.instruction("get_local", [t.numberLiteralFromRaw(1)]),
-        t.objectInstruction("min", "f64")
+        t.objectInstruction("min", "f64"),
       ],
 
-      resEqual: new f64(NaN)
+      resEqual: new f64(NaN),
     },
 
     {
@@ -778,44 +862,50 @@ describe("kernel exec - numeric instructions", () => {
 
       args: [
         { value: 0.0000000000000000000000001, type: "f64" },
-        { value: 0.00000000000000000000000001, type: "f64" }
+        { value: 0.00000000000000000000000001, type: "f64" },
       ],
 
       code: [
         t.instruction("get_local", [t.numberLiteralFromRaw(0)]),
         t.instruction("get_local", [t.numberLiteralFromRaw(1)]),
-        t.objectInstruction("min", "f64")
+        t.objectInstruction("min", "f64"),
       ],
 
-      resEqual: new f64(0.00000000000000000000000001)
+      resEqual: new f64(0.00000000000000000000000001),
     },
 
     {
       name: "f64.max",
 
-      args: [{ value: 5.0, type: "f64" }, { value: 1000.7, type: "f64" }],
+      args: [
+        { value: 5.0, type: "f64" },
+        { value: 1000.7, type: "f64" },
+      ],
 
       code: [
         t.instruction("get_local", [t.numberLiteralFromRaw(0)]),
         t.instruction("get_local", [t.numberLiteralFromRaw(1)]),
-        t.objectInstruction("max", "f64")
+        t.objectInstruction("max", "f64"),
       ],
 
-      resEqual: new f64(1000.7)
+      resEqual: new f64(1000.7),
     },
 
     {
       name: "f64.max",
 
-      args: [{ value: +0, type: "f64" }, { value: -0, type: "f64" }],
+      args: [
+        { value: +0, type: "f64" },
+        { value: -0, type: "f64" },
+      ],
 
       code: [
         t.instruction("get_local", [t.numberLiteralFromRaw(0)]),
         t.instruction("get_local", [t.numberLiteralFromRaw(1)]),
-        t.objectInstruction("max", "f64")
+        t.objectInstruction("max", "f64"),
       ],
 
-      resEqual: new f64(+0)
+      resEqual: new f64(+0),
     },
 
     {
@@ -823,44 +913,50 @@ describe("kernel exec - numeric instructions", () => {
 
       args: [
         { value: Infinity, type: "f64" },
-        { value: -Infinity, type: "f64" }
+        { value: -Infinity, type: "f64" },
       ],
 
       code: [
         t.instruction("get_local", [t.numberLiteralFromRaw(0)]),
         t.instruction("get_local", [t.numberLiteralFromRaw(1)]),
-        t.objectInstruction("max", "f64")
+        t.objectInstruction("max", "f64"),
       ],
 
-      resEqual: new f64(Infinity)
+      resEqual: new f64(Infinity),
     },
 
     {
       name: "f64.max",
 
-      args: [{ value: Infinity, type: "f64" }, { value: 1234, type: "f64" }],
+      args: [
+        { value: Infinity, type: "f64" },
+        { value: 1234, type: "f64" },
+      ],
 
       code: [
         t.instruction("get_local", [t.numberLiteralFromRaw(0)]),
         t.instruction("get_local", [t.numberLiteralFromRaw(1)]),
-        t.objectInstruction("max", "f64")
+        t.objectInstruction("max", "f64"),
       ],
 
-      resEqual: new f64(Infinity)
+      resEqual: new f64(Infinity),
     },
 
     {
       name: "f64.max",
 
-      args: [{ value: NaN, type: "f64" }, { value: 1234, type: "f64" }],
+      args: [
+        { value: NaN, type: "f64" },
+        { value: 1234, type: "f64" },
+      ],
 
       code: [
         t.instruction("get_local", [t.numberLiteralFromRaw(0)]),
         t.instruction("get_local", [t.numberLiteralFromRaw(1)]),
-        t.objectInstruction("max", "f64")
+        t.objectInstruction("max", "f64"),
       ],
 
-      resEqual: new f64(NaN)
+      resEqual: new f64(NaN),
     },
 
     {
@@ -868,17 +964,17 @@ describe("kernel exec - numeric instructions", () => {
 
       args: [
         { value: 0.0000000000000000000000001, type: "f64" },
-        { value: 0.00000000000000000000000001, type: "f64" }
+        { value: 0.00000000000000000000000001, type: "f64" },
       ],
 
       code: [
         t.instruction("get_local", [t.numberLiteralFromRaw(0)]),
         t.instruction("get_local", [t.numberLiteralFromRaw(1)]),
-        t.objectInstruction("max", "f64")
+        t.objectInstruction("max", "f64"),
       ],
 
-      resEqual: new f64(0.0000000000000000000000001)
-    }
+      resEqual: new f64(0.0000000000000000000000001),
+    },
   ];
 
   operations.forEach((op /*: TestCase*/) => {
